.. _topics-index

Welcome to Moose's documentation!
=================================

Moose是一个数据处理的自动化框架，旨在提供一套快速、灵活、便捷、幂等式的数据处理方案。它不仅提供了常用的数据处理类和函数，也提供了一套命令行式的接口以处理和维护版本内单一、重复、繁琐的任务。

.. _section-intro:

快速上手教程
=================

.. toctree::
   :caption: 快速上手教程
   :hidden:

   intro/overview
   intro/install
   intro/quickstart
   intro/examples

:doc:`intro/overview`
    了解Moose是什么以及它用于解决什么问题。

:doc:`intro/install`
    在你的电脑上安装Moose。

:doc:`intro/quickstart`
    开始你的第一个Moose项目。

:doc:`intro/examples`
    通过Moose示例了解更多。

.. _section-basics:

基本概念
=================

.. toctree::
   :caption: 基本概念
   :hidden:

   topics/commands
   topics/actions
   topics/models
   topics/order
   topics/app-templates
   topics/connections
   topics/process
   topics/settings
   topics/exceptions

:doc:`topics/commands`
    通过Moose的命令行工具来管理你的Moose项目。

:doc:`topics/actions`
    编写Action以实现你的业务逻辑。

:doc:`topics/models`
    编写Model以抽象你的数据。

:doc:`topics/order`
    定义接口，创建订单。

:doc:`topics/app-templates`
    打包app，复用代码结构。

:doc:`topics/connections`
    连接Azure，Mongo，SQLServer/MySQL以及SMB。

:doc:`topics/process`
    便捷和统一的多媒体处理类和函数。

:doc:`topics/settings`
    了解Moose的各个配置项。

:doc:`topics/exceptions`
    异常抛出说明和推荐使用惯例。


.. _section-others:

其他
=================

.. toctree::
   :caption: 其他
   :hidden:

   contributing
   news

:doc:`contributing`
    参与到Moose的开发中来！

:doc:`news`
    更新日志。
